@@ -6,6 +6,8 @@ MYPKGOPTIONS <- settings::options_manager(
   colname_for_observations = "Observations",
   colname_for_group = "Group",
   colname_for_value = "value",
+  colname_for_blocks = "block_name___",
+  colname_for_order = "order___",
   labels_TRUE_FALSE = c("yes", "no"),
   labels_Mean_SD = "Mean (SD)",
   labels_valid_missing = "valid (missing)",
@@ -91,6 +93,11 @@ MYPKGOPTIONS <- settings::options_manager(
 #'   This character will show up in the results of \code{\link{atable}}, so it can be modified.
 #'   There may be name clashes with user-supplied data.frames; so modification may be necessary.}
 #'
+#'   \item{\code{colname_for_blocks}}{: A character with length 1. Default is \code{'block_name___'}.
+#'  Used in function \code{indent_data_frame_with_blocks}.
+#'  This character will not show up in the results and is only used internally for intermediate data.frames.
+#'  There may be name clashes with user-supplied data.frames; so modification may be necessary.}
+#'
 #'   \item{\code{labels_TRUE_FALSE}}{: A character of length 2. Default is \code{c('yes', 'no')}.
 #'   Currently used in function \code{statistics.logical} (see \code{\link{statistics}}) to cast logical to factor.
 #'   \code{TRUE} is mapped to \code{labels_TRUE_FALSE[1]} and \code{FALSE} to \code{labels_TRUE_FALSE[2]}.
